#[non_exhaustive]pub enum Error {
AlreadyClosed,
CannotResolveHost,
NoUriConfigured,
DisallowedHeader,
Protocol(ProtocolError),
PayloadTooLong {
len: usize,
max_len: usize,
},
Io(Error),
NativeTls(Error),
InvalidDNSName(InvalidDnsNameError),
Rustls(Error),
UnsupportedScheme,
Upgrade(Error),
}Expand description
Generic error when using WebSockets with this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyClosed
Attempted to read from or write to a closed stream.
CannotResolveHost
DNS lookup failed.
NoUriConfigured
Available on crate feature
client only.Attempted to connect a client to a remote without configured URI.
DisallowedHeader
Available on crate features
client or server only.Attempted to add a disallowed header.
Protocol(ProtocolError)
WebSocket protocol violation.
PayloadTooLong
Payload length limit was exceeded.
Io(Error)
I/O error.
NativeTls(Error)
Available on crate feature
native-tls only.TLS error originating in native_tls.
InvalidDNSName(InvalidDnsNameError)
Available on crate features
rustls-bring-your-own-connector or rustls-native-roots or rustls-platform-verifier or rustls-webpki-roots only.Attempted to connect to an invalid DNS name.
Rustls(Error)
Available on crate features
rustls-bring-your-own-connector or rustls-native-roots or rustls-platform-verifier or rustls-webpki-roots only.A general rustls error.
UnsupportedScheme
Available on crate feature
client only.An unsupported, i.e. not ws or wss, or no URI scheme was specified.
Upgrade(Error)
Available on crate features
client or server only.The HTTP/1.1 Upgrade failed.